@@ -4,10 +4,9 @@
 #' calculated in [travel_time_matrix()], [expanded_travel_time_matrix()],
 #' [accessibility()] and [pareto_frontier()]. This fare structure can be
 #' manually edited and adjusted to the existing rules in your study area, as
-#' long as they stick to some basic premises. Please see fare structure
-#' vignette for more information on how the fare structure works:
-#' `vignette("fare_structure", package = "r5r")`.
+#' long as they stick to some basic premises. Please see the \href{../doc/fare_structure.html}{fare-structure vignette} for more information.
 #'
+#' @template r5r_network
 #' @template r5r_core
 #' @param base_fare A numeric. A base value used to populate the fare
 #'   structure.
@@ -55,13 +54,13 @@
 #' library(r5r)
 #'
 #' data_path <- system.file("extdata/poa", package = "r5r")
-#' r5r_core <- setup_r5(data_path)
+#' r5r_network <- build_network(data_path)
 #'
-#' fare_structure <- setup_fare_structure(r5r_core, base_fare = 5)
+#' fare_structure <- setup_fare_structure(r5r_network, base_fare = 5)
 #'
 #' # to debug fare calculation
 #' fare_structure <- setup_fare_structure(
-#'   r5r_core,
+#'   r5r_network,
 #'   base_fare = 5,
 #'   debug_path = "fare_debug.csv",
 #'   debug_info = "MODE"
@@ -73,12 +72,27 @@
 #' fare_structure$debug_settings <- ""
 #'
 #' @export
-setup_fare_structure <- function(r5r_core,
+setup_fare_structure <- function(r5r_network,
+                                 r5r_core = deprecated(),
                                  base_fare,
                                  by = "MODE",
                                  debug_path = NULL,
                                  debug_info = NULL) {
-  checkmate::assert_class(r5r_core, "jobjRef")
+
+  # deprecating r5r_core --------------------------------------
+  if (lifecycle::is_present(r5r_core)) {
+
+    cli::cli_warn(c(
+      "!" = "The `r5r_core` argument is deprecated as of r5r v2.3.0.",
+      "i" = "Please use the `r5r_network` argument instead."
+    ))
+
+    r5r_network <- r5r_core
+  }
+
+  # check inputs and set r5r options --------------------------------------
+  checkmate::assert_class(r5r_network, "r5r_network")
+  r5r_network <- r5r_network@jcore
   checkmate::assert_numeric(base_fare, lower = 0, len = 1, any.missing = FALSE)
 
   by_options <- c("MODE", "AGENCY_ID", "AGENCY_NAME", "GENERIC")
@@ -104,9 +118,9 @@ setup_fare_structure <- function(r5r_core,
     checkmate::assert_names(debug_info, subset.of = debug_info_options)
   }
 
-  # r5r_core method to build fare structure returns a json
+  # r5r_network method to build fare structure returns a json
 
-  f_struct <- r5r_core$buildFareStructure(rJava::.jfloat(base_fare), by)
+  f_struct <- r5r_network$buildFareStructure(rJava::.jfloat(base_fare), by)
   json_string <- f_struct$toJson()
 
   fare_structure <- jsonlite::parse_json(json_string, simplifyVector = TRUE)
@@ -153,9 +167,9 @@ setup_fare_structure <- function(r5r_core,
 #' library(r5r)
 #'
 #' data_path <- system.file("extdata/poa", package = "r5r")
-#' r5r_core <- setup_r5(data_path)
+#' r5r_network <- build_network(data_path)
 #'
-#' fare_structure <- setup_fare_structure(r5r_core, base_fare = 5)
+#' fare_structure <- setup_fare_structure(r5r_network, base_fare = 5)
 #'
 #' tmpfile <- tempfile("sample_fare_structure", fileext = ".zip")
 #' write_fare_structure(fare_structure, tmpfile)
@@ -341,7 +355,6 @@ assert_fare_structure <- function(fare_structure) {
     return(invisible(TRUE))
   } else {
     # This is an R5R fare structure object
-    
     element_names <- c(
       "max_discounted_transfers",
       "transfer_time_allowance",
