@@ -1,18 +1,20 @@
 # initial message about ram memory
-.onAttach <- function(lib, pkg) {
-  packageStartupMessage(
-    "Please make sure you have already allocated ",
-    "some memory to Java by running:\n",
-    "  options(java.parameters = '-Xmx2G').\n",
-    "You should replace '2G' by the amount of memory you'll require. ",
-    "Currently, Java memory is set to ", getOption("java.parameters")
-    )
-  }
+.onAttach <- function(lib, pkg) { # nocov start
+  msg <- cli::format_inline(
+    "Please make sure you have already allocated some memory to Java by running
+    {.code options(java.parameters = '-Xmx2G')} *before* loading library(r5r)
+
+    You should replace {.val 2G} by the amount of memory you'll need.
+    Currently, Java memory is set to {.val {getOption('java.parameters')}}."
+  )
+
+  packageStartupMessage(msg)
+  } # nocov end
 
 # package global variables
 r5r_env <- new.env(parent = emptyenv())
 
-.onLoad <- function(lib, pkg) {
+.onLoad <- function(lib, pkg) { # nocov start
 
   # JAR version
   r5r_env$r5_jar_version <- "7.4.0"
@@ -30,4 +32,4 @@ r5r_env <- new.env(parent = emptyenv())
   old_cache <- all_cache[!grepl(r5r_env$r5_jar_version, all_cache)]
   if(length(old_cache)>0){ unlink(old_cache, recursive = TRUE) }
 
-}
+} # nocov end
