@@ -1,14 +1,19 @@
-#' Calculate travel time matrix between origin destination pairs
+#' Calculate travel time matrix between origin destination pairs considering a
+#' departure time
 #'
 #' Fast computation of travel time estimates between one or multiple origin
-#' destination pairs.
+#' destination pairs. This function considers a departure time set by the user.
+#' If you want to calculate travel times considering a time of arrival, have a
+#' look at the [arrival_travel_time_matrix()] function.
 #'
+#' @template r5r_network
 #' @template r5r_core
 #' @template common_arguments
 #' @template time_window_related_args
 #' @template draws_per_minute
 #' @template fare_structure
 #' @template max_fare
+#' @template scenarios
 #' @template verbose
 #' @param percentiles An integer vector (max length of 5). Specifies the
 #'   percentile to use when returning travel time estimates within the given
@@ -41,7 +46,7 @@
 #'
 #' # build transport network
 #' data_path <- system.file("extdata/poa", package = "r5r")
-#' r5r_core <- setup_r5(data_path)
+#' r5r_network <- build_network(data_path)
 #'
 #' # load origin/destination points
 #' points <- read.csv(file.path(data_path, "poa_points_of_interest.csv"))
@@ -52,7 +57,7 @@
 #' )
 #'
 #' ttm <- travel_time_matrix(
-#'   r5r_core,
+#'   r5r_network,
 #'   origins = points,
 #'   destinations = points,
 #'   mode = c("WALK", "TRANSIT"),
@@ -63,7 +68,7 @@
 #'
 #' # using a larger time window
 #' ttm <- travel_time_matrix(
-#'   r5r_core,
+#'   r5r_network,
 #'   origins = points,
 #'   destinations = points,
 #'   mode = c("WALK", "TRANSIT"),
@@ -75,7 +80,7 @@
 #'
 #' # selecting different percentiles
 #' ttm <- travel_time_matrix(
-#'   r5r_core,
+#'   r5r_network,
 #'   origins = points,
 #'   destinations = points,
 #'   mode = c("WALK", "TRANSIT"),
@@ -92,7 +97,7 @@
 #'   file.path(data_path, "fares/fares_poa.zip")
 #' )
 #' ttm <- travel_time_matrix(
-#'   r5r_core,
+#'   r5r_network,
 #'   origins = points,
 #'   destinations = points,
 #'   mode = c("WALK", "TRANSIT"),
@@ -103,10 +108,11 @@
 #' )
 #' head(ttm)
 #'
-#' stop_r5(r5r_core)
+#' stop_r5(r5r_network)
 #'
 #' @export
-travel_time_matrix <- function(r5r_core,
+travel_time_matrix <- function(r5r_network,
+                               r5r_core = deprecated(),
                                origins,
                                destinations,
                                mode = "WALK",
@@ -114,8 +120,6 @@ travel_time_matrix <- function(r5r_core,
                                departure_datetime = Sys.time(),
                                time_window = 10L,
                                percentiles = 50L,
-                               fare_structure = NULL,
-                               max_fare = Inf,
                                max_walk_time = Inf,
                                max_bike_time = Inf,
                                max_car_time = Inf,
@@ -124,17 +128,31 @@ travel_time_matrix <- function(r5r_core,
                                bike_speed = 12,
                                max_rides = 3,
                                max_lts = 2,
+                               fare_structure = NULL,
+                               max_fare = Inf,
+                               new_carspeeds = NULL,
+                               carspeed_scale = 1,
+                               new_lts = NULL,
                                draws_per_minute = 5L,
                                n_threads = Inf,
                                verbose = FALSE,
                                progress = FALSE,
                                output_dir = NULL) {
 
+  # deprecating r5r_core --------------------------------------
+  if (lifecycle::is_present(r5r_core)) {
+
+    cli::cli_warn(c(
+      "!" = "The `r5r_core` argument is deprecated as of r5r v2.3.0.",
+      "i" = "Please use the `r5r_network` argument instead."
+    ))
+
+    r5r_network <- r5r_core
+  }
+
   old_options <- options(datatable.optimize = Inf)
   on.exit(options(old_options), add = TRUE)
 
-  checkmate::assert_number(n_threads, lower = 1)
-
   old_dt_threads <- data.table::getDTthreads()
   dt_threads <- ifelse(is.infinite(n_threads), 0, n_threads)
   data.table::setDTthreads(dt_threads)
@@ -142,16 +160,23 @@ travel_time_matrix <- function(r5r_core,
 
   # check inputs and set r5r options --------------------------------------
 
-  checkmate::assert_class(r5r_core, "jobjRef")
+  checkmate::assert_class(r5r_network, "r5r_network")
+  r5r_network <- r5r_network@jcore
 
   origins <- assign_points_input(origins, "origins")
   destinations <- assign_points_input(destinations, "destinations")
   mode_list <- assign_mode(mode, mode_egress)
   departure <- assign_departure(departure_datetime)
 
+  # in direct modes reverse origin/destination to take advantage of R5's One to Many algorithm
+  data_path <- r5r_network$getDataPath()
+  res <- reverse_if_direct_mode(origins, destinations, mode_list, data_path)
+  origins <- res$origins
+  destinations <- res$destinations
+
   # check availability of transit services on the selected date
   if (mode_list$transit_mode %like% 'TRANSIT|TRAM|SUBWAY|RAIL|BUS|CABLE_CAR|GONDOLA|FUNICULAR') {
-    check_transit_availability_on_date(r5r_core, departure_date = departure$date)
+    check_transit_availability_on_date(r5r_network, departure_date = departure$date)
   }
 
   max_walk_time <- assign_max_street_time(
@@ -179,25 +204,31 @@ travel_time_matrix <- function(r5r_core,
     max_bike_time
   )
 
-  set_time_window(r5r_core, time_window)
-  set_percentiles(r5r_core, percentiles)
-  set_monte_carlo_draws(r5r_core, draws_per_minute, time_window)
-  set_speed(r5r_core, walk_speed, "walk")
-  set_speed(r5r_core, bike_speed, "bike")
-  set_max_rides(r5r_core, max_rides)
-  set_max_lts(r5r_core, max_lts)
-  set_n_threads(r5r_core, n_threads)
-  set_verbose(r5r_core, verbose)
-  set_progress(r5r_core, progress)
-  set_fare_structure(r5r_core, fare_structure)
-  set_max_fare(r5r_core, max_fare)
-  set_output_dir(r5r_core, output_dir)
-  set_expanded_travel_times(r5r_core, FALSE)
-  set_breakdown(r5r_core, FALSE)
+  set_time_window(r5r_network, time_window)
+  set_percentiles(r5r_network, percentiles)
+  set_monte_carlo_draws(r5r_network, draws_per_minute, time_window)
+  set_speed(r5r_network, walk_speed, "walk")
+  set_speed(r5r_network, bike_speed, "bike")
+  set_max_rides(r5r_network, max_rides)
+  set_max_lts(r5r_network, max_lts)
+  set_n_threads(r5r_network, n_threads)
+  set_verbose(r5r_network, verbose)
+  set_progress(r5r_network, progress)
+  set_fare_structure(r5r_network, fare_structure)
+  set_max_fare(r5r_network, max_fare)
+  set_output_dir(r5r_network, output_dir)
+  set_expanded_travel_times(r5r_network, FALSE)
+  set_breakdown(r5r_network, FALSE)
+  r5r_network$setSearchType("DEPART_FROM")
 
-  # call r5r_core method and process result -------------------------------
+  # SCENARIOS -------------------------------------------
+  set_new_congestion(r5r_network, new_carspeeds, carspeed_scale)
+  set_new_lts(r5r_network, new_lts)
 
-  travel_times <- r5r_core$travelTimeMatrix(
+
+  # call r5r_network method and process result -------------------------------
+
+  travel_times <- r5r_network$travelTimeMatrix(
     origins$id,
     origins$lat,
     origins$lon,
