@@ -6,7 +6,8 @@ testthat::skip_on_cran()
 # expected behavior
 test_that("street_network_to_sf - expected behavior", {
 
-  testthat::expect_type( street_network_to_sf(r5r_core), 'list')
+  testthat::expect_type( street_network_to_sf(r5r_network), 'list')
+
 })
 
 
@@ -16,4 +17,9 @@ test_that("street_network_to_sf - expected errors", {
 
   # invalid input
   testthat::expect_error( street_network_to_sf('a') )
+
+
+  # warning due to deprecated argument
+  testthat::expect_warning( street_network_to_sf(r5r_core=r5r_network))
+
   })
