@@ -5,7 +5,7 @@ testthat::skip_on_cran()
 # expected behavior
 test_that("transit_network_to_sf - expected behavior", {
 
-  testthat::expect_type( transit_network_to_sf(r5r_core), 'list')
+  testthat::expect_type( transit_network_to_sf(r5r_network), 'list')
 })
 
 
